==> unit-1.0.25-sources.jar: io/intino/goros/unit/box/ui/displays/items/RolesTableTypeItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class RolesTableTypeItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Role, UnitBox> {
	public _46_52_0828576289 _46_52_0828576289;
	public RolesTableTypeItem._46_52_0828576289. Type type;

    public RolesTableTypeItem(UnitBox box) {
        super(box);
        id("a1140630920");
    }

    @Override
	public void init() {
		super.init();
		if (_46_52_0828576289 == null) _46_52_0828576289 = register(new _46_52_0828576289(box()).<_46_52_0828576289>id("a_499362950").owner(RolesTableTypeItem.this));
		if (_46_52_0828576289 != null) type = _46_52_0828576289.type;
	}

	public class _46_52_0828576289 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public RolesTableTypeItem._46_52_0828576289. Type type;

		public _46_52_0828576289(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (type == null) type = register(new Type(box()).<Type>id("a270682561").owner(RolesTableTypeItem.this));
		}

		public class Type extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Type(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/items/RolesTableTypeItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class RolesTableTypeItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Role, UnitBox> {
	public _46_52_0828576289 _46_52_0828576289;
	public RolesTableTypeItem._46_52_0828576289. Type type;

    public RolesTableTypeItem(UnitBox box) {
        super(box);
        id("a1140630920");
    }

    @Override
	public void init() {
		super.init();
		if (_46_52_0828576289 == null) _46_52_0828576289 = register(new _46_52_0828576289(box()).<_46_52_0828576289>id("a_499362950").owner(RolesTableTypeItem.this));
		if (_46_52_0828576289 != null) type = _46_52_0828576289.type;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_46_52_0828576289 != null) _46_52_0828576289.unregister();
	}

	public class _46_52_0828576289 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public RolesTableTypeItem._46_52_0828576289. Type type;

		public _46_52_0828576289(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (type == null) type = register(new Type(box()).<Type>id("a270682561").owner(RolesTableTypeItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (type != null) type.unregister();
		}

		public class Type extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Type(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
